#include <Servo.h>
#include <Keypad.h>

/*
Control del servo desde el keypad
*/

int servoPin = 3;
Servo miServo;

//keypad
const byte ROWS = 4; //four rows
const byte COLS = 4; //four columns

//matriz de mapeo del teclado
char keys[ROWS][COLS] = {
  {'1','2','3','A'},
  {'4','5','6','B'},
  {'7','8','9','C'},
  {'*','0','#','D'}
};

//conexión de filas y columnas del keypad al Arduino
byte rowPins[ROWS] = {13, 12, 11, 10}; //connect to the row pinouts of the keypad
byte colPins[COLS] = {8, 7, 6, 5}; //connect to the column pinouts of the keypad

// creación del objeto teclado
Keypad teclado = Keypad( makeKeymap(keys), rowPins, colPins, ROWS, COLS );

int angulo, controlVelocidad;

bool teclaA, teclaB;

void setup() {
  Serial.begin(9600);
  miServo.attach(servoPin);

  miServo.write(0);
  angulo = 0;
  controlVelocidad = 10;

  teclaA = false;
  teclaB = false;

  //colocamos un event listener para captura eventos del keypad
  teclado.addEventListener(keypadEvent);
}

void loop() {
  /* cuando mantengamos ajustada la tecla A, el servo
  gira en un sentido, y al ajustar la tecla B, gira
  en sentido inverso, entre 0 y 180 grados
  */

  char tecla = teclado.getKey();

  if (teclaA){
    angulo++;
    if (angulo >= 180) angulo = 180;
    miServo.write(angulo);
    delay(controlVelocidad);
  }

  if (teclaB){
    angulo--;
    if (angulo <= 0) angulo = 0;
    miServo.write(angulo);
    delay(controlVelocidad);
  }
}

// capturamos eventos del keypad
void keypadEvent(KeypadEvent tecla){
  
  switch (teclado.getState()){
    case PRESSED:
      if (tecla == 'A'){
        teclaA = true;

      }else if (tecla == 'B'){
        teclaB = true;
      }

      break;

    case RELEASED:
      if (tecla == 'A'){
        teclaA = false;

      }else if (tecla == 'B'){
        teclaB = false;
      }
      break;    
  }
}
